@@ -17,21 +17,16 @@ INSERT INTO dem.message_inbox (
 ) VALUES (
 	(select pk from dem.staff where db_user = 'any-doc'),
 	(select pk_type from dem.v_inbox_item_type where type = 'memo' and category = 'administrative'),
-	'Release Notes for GNUmed 1.3.7 (database v18.7)',
-	'GNUmed 1.3.7 Release Notes:
+	'Release Notes for GNUmed 1.3.9 (database v18.9)',
+	'GNUmed 1.3.9 Release Notes:
 
-	1.3.7
+	1.3.9
 
-FIX: exception on substance intake w/o start date [thanks Jim]
-FIX: faulty SQL in lab phrasewheel [thanks Jim]
-FIX: exception on saving modified organization [thanks Jim]
-FIX: validity check on substance discontinuation date [thanks Jim]
-FIX: exception on accessing org unit comm channel comment [thanks Jim]
-FIX: failure to properly delete org *units* [thanks Jim]
-FIX: failure to properly edit substance intakes [thanks Jim]
+FIX: health issue EA hang [thanks Jim]
+FIX: exception on creating inbox item type which already exists under different category
 
-IMPROVED: show substance intolerances in magenta rather than yellow [thanks Jim]
+IMPROVED: generate PDF from AbiWord generated forms
 ');
 
 -- --------------------------------------------------------------
-select gm.log_script_insertion('v18-release_notes-dynamic.sql', '18.5');
+select gm.log_script_insertion('v18-release_notes-dynamic.sql', '18.9');
